@@ -29,7 +29,9 @@ def _venue_models(
             venue_identity = venue_identity_map.get(game_model_venue.identifier)
             if venue_identity is None:
                 logging.warning(
-                    "Failed to find %s venue identifier.", game_model_venue.identifier
+                    "Failed to find %s venue identifier (%s).",
+                    game_model_venue.identifier,
+                    game_model_venue.name,
                 )
             else:
                 full_venue_identity = venue_identity
@@ -55,7 +57,9 @@ def _team_models(
                 team_identity = team_identity_map.get(team_model.identifier)
                 if team_identity is None:
                     logging.warning(
-                        "Failed to find %s team identifier.", team_model.identifier
+                        "Failed to find %s team identifier (%s).",
+                        team_model.identifier,
+                        team_model.name,
                     )
                     team_identity = team_model.identifier
                 team_models[team_identity] = team_models.get(team_identity, []) + [
