@@ -27,9 +27,10 @@ class Position(StrEnum):
     DEFENSIVE_MIDFIELDER = "DM"
     CENTRE_FORWARD_LEFT = "CF-L"
     CENTRE_FORWARD_RIGHT = "CF-R"
+    SWEEPER = "SW"
 
 
-_POSITIONS = {**{str(x): x for x in Position}, **{"RCF": Position.CENTRE_FORWARD_RIGHT}}
+_POSITIONS = {str(x): x for x in Position}
 
 
 def position_from_str(position_str: str) -> Position:
