@@ -22,11 +22,12 @@ def _season_type_from_name(name: str) -> SeasonType:
         or "English Premier League" in name
         or "Group Stage" in name
         or "Spring Regular Season" in name
+        or "Round of" in name
     ):
         return SeasonType.REGULAR
     if name == "Preseason" or "Spring Training" in name:
         return SeasonType.PRESEASON
-    if name == "Postseason":
+    if name == "Postseason" or "Quarterfinals" in name:
         return SeasonType.POSTSEASON
     if name == "Off Season":
         return SeasonType.OFFSEASON
