@@ -15,3 +15,5 @@ class Position(StrEnum):
     FIRST_BASEMAN = "1B"
     CENTRE_FIELDER = "CF"
     THIRD_BASEMAN = "3B"
+    PINCH_RUNNER = "PR"
+    PITCHER = "P"
