@@ -9,6 +9,11 @@ class Position(StrEnum):
 
     POWER_FORWARD = "PF"
     SHORT_GUARD = "SG"
+    SMALL_FORWARD = "SF"
+    CENTRE = "C"
+    POINT_GUARD = "PG"
+    GUARD = "G"
+    FORWARD = "F"
 
 
 _POSITIONS = {str(x): x for x in Position}
