@@ -110,6 +110,9 @@ def create_sportsdb_game_model(
     season_type: SeasonType | None,
 ) -> GameModel | None:
     """Create a SportsDB game model."""
+    if isinstance(game, str):
+        return None
+
     try:
         ts = game["strTimestamp"]
         if ts is None:
@@ -119,6 +122,9 @@ def create_sportsdb_game_model(
         dt = datetime.datetime.fromisoformat(ts)
     except TypeError:
         dt = parser.parse(game["dateEvent"])
+    if dt > datetime.datetime.now().replace(tzinfo=dt.tzinfo):
+        return None
+
     if not pytest_is_running.is_running() and dt < datetime.datetime.now().replace(
         tzinfo=dt.tzinfo
     ) - datetime.timedelta(days=7):
